==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Group list is empty" : "L'elenco dei gruppi è vuoto",
    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
    "Saved" : "Salvato",
    "Saving failed:" : "Salvataggio non riuscito:",
    "File MIME type" : "Tipo MIME del file",
    "is" : "è",
    "is not" : "non è",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "Example: {placeholder}" : "Esempio: {placeholder}",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Select tag…" : "Seleziona etichetta...",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Start" : "Inizio",
    "End" : "Fine",
    "Select timezone…" : "Seleziona fuso orario...",
    "Request URL" : "URL della richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Request user agent" : "User agent della richiesta",
    "Sync clients" : "Client di sincronizzazione",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di",
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Workflow" : "Flusso di lavoro",
    "Files workflow engine" : "Motore delle procedure dei file",
    "Open documentation" : "Apri documentazione",
    "Add rule group" : "Aggiungi gruppo di regole",
    "Short rule description" : "Descrizione breve della regola",
    "Add rule" : "Aggiungi regola",
    "Reset" : "Ripristina",
    "Save" : "Salva",
    "Saving…" : "Salvataggio in corso...",
    "Loading…" : "Caricamento in corso..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/it.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Group list is empty" : "L'elenco dei gruppi è vuoto",
    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
    "Saved" : "Salvato",
    "Saving failed:" : "Salvataggio non riuscito:",
    "File MIME type" : "Tipo MIME del file",
    "is" : "è",
    "is not" : "non è",
    "matches" : "corrisponde",
    "does not match" : "non corrisponde",
    "Example: {placeholder}" : "Esempio: {placeholder}",
    "File name" : "Nome file",
    "File size (upload)" : "Dimensione file (caricamento)",
    "less" : "minore",
    "less or equals" : "minore o uguale",
    "greater or equals" : "maggiore o uguale",
    "greater" : "maggiore",
    "File system tag" : "Etichetta del file system",
    "is tagged with" : "è etichettato con",
    "is not tagged with" : "non è etichettato con",
    "Select tag…" : "Seleziona etichetta...",
    "Request remote address" : "Indirizzo remoto della richiesta",
    "matches IPv4" : "corrisponde a IPv4",
    "does not match IPv4" : "non corrisponde a IPv4",
    "matches IPv6" : "corrisponde a IPv6",
    "does not match IPv6" : "non corrisponde a IPv6",
    "Request time" : "Ora della richiesta",
    "between" : "compreso",
    "not between" : "non compreso",
    "Start" : "Inizio",
    "End" : "Fine",
    "Select timezone…" : "Seleziona fuso orario...",
    "Request URL" : "URL della richiesta",
    "Predefined URLs" : "URL predefiniti",
    "Files WebDAV" : "File WebDAV",
    "Request user agent" : "User agent della richiesta",
    "Sync clients" : "Client di sincronizzazione",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client desktop",
    "Thunderbird & Outlook addons" : "Componenti aggiuntivi di Outlook e Thunderbird",
    "User group membership" : "Appartenenza ai gruppi degli utenti",
    "is member of" : "è membro di",
    "is not member of" : "non è membro di",
    "The given operator is invalid" : "L'operatore specificato non è valido",
    "The given regular expression is invalid" : "L'espressione regolare specificata non è valida",
    "The given file size is invalid" : "La dimensione del file specificata non è valida",
    "The given tag id is invalid" : "L'etichetta specificata non è valida",
    "The given IP range is invalid" : "L'intervallo di IP specificato non è valido",
    "The given IP range is not valid for IPv4" : "L'intervallo di IP specificato non è valido per IPv4",
    "The given IP range is not valid for IPv6" : "L'intervallo di IP specificato non è valido per IPv6",
    "The given time span is invalid" : "L'intervallo di tempo specificato non è valido",
    "The given start time is invalid" : "L'ora di inizio specificata non è valida",
    "The given end time is invalid" : "L'ora di fine specificata non è valida",
    "The given group does not exist" : "Il gruppo specificato non esiste",
    "Check %s is invalid or does not exist" : "Il controllo %s non è valido o non esiste",
    "Operation #%s does not exist" : "L'operazione #%s non esiste",
    "Operation %s does not exist" : "L'operazione %s non esiste",
    "Operation %s is invalid" : "L'operazione %s non è valida",
    "Check %s does not exist" : "Il controllo %s non esiste",
    "Check %s is invalid" : "Il controllo %s non è valido",
    "Check #%s does not exist" : "Il controllo #%s non esiste",
    "Workflow" : "Flusso di lavoro",
    "Files workflow engine" : "Motore delle procedure dei file",
    "Open documentation" : "Apri documentazione",
    "Add rule group" : "Aggiungi gruppo di regole",
    "Short rule description" : "Descrizione breve della regola",
    "Add rule" : "Aggiungi regola",
    "Reset" : "Ripristina",
    "Save" : "Salva",
    "Saving…" : "Salvataggio in corso...",
    "Loading…" : "Caricamento in corso..."
},
"nplurals=2; plural=(n != 1);");
